#!/usr/bin/python3
import os
import json
import sys
from PyQt5 import QtGui, QtWidgets, QtCore, QtDBus

LOCAL_DIR = os.path.dirname(os.path.realpath(__file__)) + '/'


class Main(QtCore.QObject):
    execute = QtCore.pyqtSignal(str)

    def __init__(self, parent):
        super().__init__()
        self.name = "desktop bus"
        self.preferences = parent.preferences
        self.log = parent.logger.new(self.name.title())

        service = "org.freedesktop.login1"
        if QtDBus.QDBusConnection.systemBus().interface().isServiceRegistered(service).value():
            path = "/org/freedesktop/login1"
            interface = "org.freedesktop.login1.Manager"
            name = "PrepareForShutdown"
            self.bus = QtDBus.QDBusConnection.systemBus()
            self.bus.connect(service, path, interface, "PrepareForShutdown", self._prepareForShutdown)
            self.bus.connect(service, path, interface, "PrepareForSleep", "b", self._prepareForSleep)

    def _getParameters(self, trigger):
        enabled, action = self.preferences.get("actions", "desktop bus", trigger)
        command = self.preferences.get("exec", "desktop bus", trigger)
        return enabled, action, command

    @QtCore.pyqtSlot()
    def _prepareForShutdown(self):
        enabled, action, command = self._getParameters("prepare for shutdown")
        if enabled and action == "Exec":
            self.log.info("Prepare for shutdown")
            self.execute.emit(command)

    @QtCore.pyqtSlot(bool)
    def _prepareForSleep(self, state):
        if state:
            enabled, action, command = self._getParameters("prepare for sleep")
            self.log.info("Prepare for sleep")
        else:
            enabled, action, command = self._getParameters("resume from sleep")
            self.log.info("Resume from sleep")

        if enabled and action == "Exec":
            self.execute.emit(command)
